/* BdfServer_JsonProducers - Copyright (c) 2017-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.CorpusDomain;
import fr.exemole.bdfserver.jsonproducers.ResultJsonProducer;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.thesaurus.Thesaurus;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public final class CorpusJsonProducerFactory {

    private CorpusJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws ErrorMessageException {
        String json = parameters.getOutput();
        BdfServer bdfServer = parameters.getBdfServer();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        RequestMap requestMap = parameters.getRequestMap();
        Lang lang = parameters.getWorkingLang();
        ResultJsonProducer jsonProducer = new ResultJsonProducer(bdfCommandResult, parameters.getMessageLocalisation());
        switch (json) {
            case CorpusDomain.UI_JSON: {
                Corpus corpus = BdfInstructionUtils.getMandatoryCorpus(bdfServer.getFichotheque(), requestMap);
                jsonProducer.add(new UiJsonProperty(corpus, lang, bdfServer.getUiManager().getMainUiComponents(corpus)));
                break;
            }
            case CorpusDomain.REMOVEDLIST_JSON: {
                Corpus corpus = BdfInstructionUtils.getMandatoryCorpus(bdfServer.getFichotheque(), requestMap);
                jsonProducer.add(new LastRevisionsProperty(bdfServer, corpus.getRemovedFicheHistoryList()));
                break;
            }
            case CorpusDomain.CROISEMENTHISTORYLIST_JSON: {
                Corpus corpus = BdfInstructionUtils.getMandatoryCorpus(bdfServer.getFichotheque(), requestMap);
                int id = BdfInstructionUtils.getMandatoryId(requestMap);
                Thesaurus thesaurus = BdfInstructionUtils.getMandatoryThesaurus(bdfServer.getFichotheque(), requestMap);
                jsonProducer.add(new CroisementHistoryArrayProperty(corpus.getCroisementHistoryList(id, thesaurus.getSubsetKey())));
                break;
            }
        }
        if (jsonProducer.isEmpty()) {
            return null;
        } else {
            return jsonProducer;
        }
    }

}
